==> haskell-lens-aeson-1.2.3-179-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-CCNhaOV43Z0Gh5KmTBUo6E
key:                  lens-aeson-1.2.3-CCNhaOV43Z0Gh5KmTBUo6E
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  1b7dc97717ae7c78b305496048731419
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-CCNhaOV43Z0Gh5KmTBUo6E
depends:
    aeson-2.1.2.1-nTcMAwSjFOFbKrX5mWkol base-4.17.2.1
    bytestring-0.11.5.3 lens-5.3.2-fiszOW9VlT8rCDJtY0rRn
    scientific-0.3.8.0-K9UnBgGB9Y7F763TSfYqCQ text-2.0.2
    text-short-0.1.6-EVf6vrikVI7BQfpzDXdt5t
    unordered-containers-0.2.20-KDi8IgRcOV5HCm7hBAqDWV
    vector-0.13.2.0-FDZBPFjQhmHDghUn2Zh3lL

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lens-aeson-1.2.3-180-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lens-aeson.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lens-aeson
version:              1.2.3
visibility:           public
id:                   lens-aeson-1.2.3-Jk1L2IQrrvp7ASB1xszZjZ
key:                  lens-aeson-1.2.3-Jk1L2IQrrvp7ASB1xszZjZ
license:              MIT
copyright:
    Copyright (C) 2012 Paul Wilson
    Copyright (C) 2013 Edward A. Kmett

maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/lens/lens-aeson/
synopsis:             Law-abiding lenses for aeson
description:          Law-abiding lenses for aeson.
category:             Data, JSON, Lenses
abi:                  abf776844e83fbfd9f958643ab32c292
exposed:              True
exposed-modules:      Data.Aeson.Lens
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lens-aeson-1.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lens-aeson
hs-libraries:         HSlens-aeson-1.2.3-Jk1L2IQrrvp7ASB1xszZjZ
depends:
    aeson-2.1.2.1-1NeIvw5bSkQ9apxHmCtPBl base-4.17.2.1
    bytestring-0.11.5.3 lens-5.3.2-3lnPesktvu71I24tA5AXig
    scientific-0.3.8.0-5UF0voSgI45snHwsluIty text-2.0.2
    text-short-0.1.6-L2MeS8ccPsd8TFkZJEeMI
    unordered-containers-0.2.20-1s4f8pAJmee27mGfYrIk99
    vector-0.13.2.0-JPy5pohpq8EDknIfFhMz6E

haddock-interfaces:   /usr/share/doc/haskell-lens-aeson/html/lens-aeson.haddock
haddock-html:         /usr/share/doc/haskell-lens-aeson/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
